==> wcag-algorithms-1.28.2-sources.jar: org/verapdf/wcag/algorithms/entities/SemanticHeading.java <==
/*
 * This file is part of veraPDF wcag algorithms, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF wcag algorithms is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF wcag algorithms as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF wcag algorithms as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.wcag.algorithms.entities;

import org.verapdf.wcag.algorithms.entities.enums.SemanticType;

public class SemanticHeading extends SemanticParagraph {

	public SemanticHeading(SemanticHeading heading) {
		super(heading);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading(SemanticParagraph paragraph) {
		super(paragraph);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading(SemanticSpan span) {
		super(span);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading(SemanticPart part) {
		super(part);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading(SemanticTextNode textNode) {
		super(textNode);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading() {
		setSemanticType(SemanticType.HEADING);
	}
}

==> wcag-algorithms-1.29.12-sources.jar: org/verapdf/wcag/algorithms/entities/SemanticHeading.java <==
/**
 * This file is part of veraPDF wcag algorithms, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF wcag algorithms is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF wcag algorithms as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF wcag algorithms as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.wcag.algorithms.entities;

import org.verapdf.wcag.algorithms.entities.enums.SemanticType;

public class SemanticHeading extends SemanticParagraph {

	private Integer headingLevel;

	public SemanticHeading(SemanticHeading heading) {
		super(heading);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading(SemanticParagraph paragraph) {
		super(paragraph);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading(SemanticSpan span) {
		super(span);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading(SemanticPart part) {
		super(part);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading(SemanticTextNode textNode) {
		super(textNode);
		setSemanticType(SemanticType.HEADING);
	}

	public SemanticHeading() {
		setSemanticType(SemanticType.HEADING);
	}

	public Integer getHeadingLevel() {
		return headingLevel;
	}

	public void setHeadingLevel(Integer headingLevel) {
		this.headingLevel = headingLevel;
	}
}
